class syleniumConfigValueError(ValueError):
    """
    When configuration options specified often by a user provided yaml do not adhere to syleniums constraints this is
    raised.
    """

    pass
