CHROME = "chrome"
FIREFOX = "firefox"
BROWSER_RESOLUTION = "1280x1024"
BROWSER_VERSION = "latest"
BROWSER_BINARY_PATH = "acquire"
CSS = "css"
GRID_LOCALHOST = "http://127.0.0.1:4444/wd/hub"
sylenium_CONFIGURATION = "sylenium_CONFIGURATION"
